<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    safetag
 * @subpackage safetag/admin/partials
 */

$pending_keyword_result = Safetag_Db_Management::is_pending_keywords_result_by_post_id($post->ID);
$is_pending_keyword_result = count( $pending_keyword_result ) > 0;


$keyword_result = Safetag_Db_Management::get_keywords_result_by_post_id($post->ID);

$keyword_result = array_map(function ($value) {
    return [
        "id" => $value->id,
        "name" => $value->name,
        "type" => Safetag_Cron_Job::$campaign_type[$value->type]['key'],
        "keywords" => $value->keywords
    ];
}, $keyword_result);

$keyword_result_by_type = Safetag_Cron_Job::_group_by($keyword_result, 'type');

$campaign_type = Safetag_Cron_Job::$campaign_type;
rsort($campaign_type);

$whitelist = isset($keyword_result_by_type['whitelist'])
    ?   array_filter($keyword_result_by_type['whitelist'], function ($value) {
        return $value['type'] = 'whitelist';
    })
    : [];

$blacklist = isset($keyword_result_by_type['blacklist'])
    ?
    array_filter($keyword_result_by_type['blacklist'], function ($value) {
        return $value['type'] = 'blacklist';
    })
    : [];

$index  = max([count($whitelist), count($blacklist)]);


// Add a nonce field so we can check for it later.
wp_nonce_field('safetag_meta_box_notice_nonce', 'safetag_meta_box_notice_nonce');

$safetag_hide_programmatic_ads = get_post_meta($post->ID, 'safetag_hide_programmatic_ads', true);
$safetag_iab_tag_option_enable = get_option('safetag_iab_tag_option');
$value = get_post_meta($post->ID, 'safetag_meta_tags', true);
?>
<div class="safetag-wrap safetag-full-width">

    <!-- <div class="bold safetag-meta-title">Hide Programmatic Ads</div>
    <p class="safetag-mt-0">Programmatic ads are shown by default. You can hide them for this content. Typically used for Sponsorships, Brand Safety, etc.</p>

    <div class="safetag-mb-20">
        <label class="switch">
            <input type="checkbox" name="nds[safetag_hide_programmatic_ads]" <?php echo $safetag_hide_programmatic_ads != '' ? ' checked="checked" ' : ''; ?>>
            <span class=" slider round"></span>
        </label>
    </div> -->

    <?php if ($safetag_iab_tag_option_enable == 'on') { ?>

        <div class="bold safetag-meta-title">IAB Tags</div>
        <p class="safetag-mt-0">For more targeted ads categorize this content with industry standard tags.</p>

        <input type="hidden" name="safetag_meta_tags_values" id="safetag_meta_tags_values" value='<?php echo esc_html($value); ?>'>
        <select autocapitalize="off" name="nds[safetag_meta_tags][]" id="select-tools"></select>
    <?php } ?>

    <p class="bold safetag-meta-title safetag-mt-20">Keyword Results</p>
    <!-- <p class="safetag-mtb-0">Content must be saved to display results.</p> -->

    <table class="form-table">
        <thead>
            <tr>
                <?php for ($i = 0; $i < count($campaign_type); $i++) { ?>
                    <th><?php echo esc_html($campaign_type[$i]['name']); ?></th>
                <?php } ?>
            </tr>
        </thead>
        <tbody>
            
            <?php if($index == 0) :?>
                <tr>
                    <td>none</td>
                    <td>none</td>
                </tr>
            <?php endif;?>
            <?php
            for ($i = 0; $i < $index; $i++) {
            ?>
                <tr>
                    <?php if(count($whitelist)==0 && $i == 0):?>
                        <td>none</td>
                    <?php elseif(count($whitelist)==0 && $i != 0):?>
                        <td></td>
                    <?php else:?>
                        <td><?php echo isset($whitelist[$i]) ? esc_html($whitelist[$i]['name']) : '' ?></td>
                    <?php endif;?>
                    <?php if(count($blacklist)==0 && $i == 0):?>
                        <td>none</td>
                    <?php elseif(count($blacklist)==0 && $i != 0):?>
                        <td></td>
                    <?php else:?>
                        <td><?php echo isset($blacklist[$i]) ? esc_html($blacklist[$i]['name']) : '' ?></td>
                    <?php endif;?>
                </tr>
            <?php
            }
            ?>
        </tbody>
    </table>

    <?php if ($is_pending_keyword_result) { ?>
      <p style="color: red;"> Following Campaign result will be available in a few moments.</p>

      <table class="form-table">
        <thead>
            <tr>
              <th>Campaign</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach( $pending_keyword_result as $campaign) : ?>
                <tr>
                    <td><?php echo esc_html($campaign->name); ?></td>
                </tr>
            <?php endforeach; ?>
        </tbody>
    </table>

    <?php } ?>
</div>
