<?php

if (!class_exists('WP_List_Table')) {
  require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}
class DisplayCampaingList extends WP_List_Table {
    function __construct() {
        parent::__construct([
          'singular' => 'Campaing',
          'plural' => 'Campaings',
          'ajax' => false
        ]);
      }

    function get_columns(){
      $columns = array(
        'name' => 'Campaign Name',
        'type'    => 'Type',
        'created_at'      => 'Created',
        'active'    => 'Status',
        'posts'     => 'Posts',
        'actions'  => "Action"
      );
      return $columns;
    }

    protected function column_default($item, $column_name) {
      $campaign_type = Safetag_Cron_Job::$campaign_type;
      switch ($column_name) {
        case 'name' :
          return $item[$column_name];
          break;
          case 'type' :
            return $campaign_type[$item['type']]['name'];
            break;
        case 'created_at':
          return date('m-d-Y | g:i a', strtotime($item['created_at']));
          break;
        case 'active' : 
          return $item['active'] ? 'Active' : 'Inactive';
          break;
        case  'posts' :
          $res = $this->post_count();
          if(!empty($res[$item['id']])){
            return $res[$item['id']]; 
          }
          return null;
          break;
        default :
          return isset($item->column_name) ? $item->column_name : '';
      }
    }
    public function column_actions($item){
      $page = sanitize_text_field($_GET['page']);
      $edit = Safetag_Admin::generate_url([ "setting_seccion" => "exclusion-list-edit", "pid" => $item['id']], $page);
      $delete = Safetag_Admin::generate_url(["setting_seccion" => "exclusion-list-delete", "pid" => $item['id']], $page);
      $export = Safetag_Admin::generate_url(["setting_seccion" => "exclusion-list-export", "pid" => $item['id']], $page);
      $report = Safetag_Admin::generate_url(["setting_seccion" => "exclusion-list-report", "pid" => $item['id'],   "slice_number" => 0], $page);

      return '<a href="' . $edit . '">EDIT</a> | <a href="'.$delete .'">DELETE</a> | <a href="' . $export . '">EXPORT</a> | <a href="'. $report .'">REPORT</a>';
    }
    public function prepare_items() {
      $column = $this->get_columns();
      $hidden = [];
      $sortable = $this->get_sortable_columns();
      $par_page = 20;
      $current_page = $this->get_pagenum();
      $offset = ($current_page -1) * $par_page;
      $this->_column_headers = [$column, $hidden, $sortable];
      $args = [
        'per_page' => $par_page,
        'offset' => $offset,
      ];
      if(isset($_REQUEST['orderby']) && isset($_REQUEST['order'])){
        $args['orderby'] = sanitize_sql_orderby( $_REQUEST['orderby']);
        $args['order'] = sanitize_text_field( $_REQUEST['order']);
      }
      $res = Safetag_Db_Management::get_exclusion_list_records($offset,$par_page,"'name', 'active', 'created_at'",'ASC');
      $this->items = $this->get_items($args);
      
      $this->set_pagination_args([
        'total_items' => $this->total_count(),
        'per_page' => $par_page,
      ]);
    }

    private function total_count(){
      global $wpdb;
      return (int) $wpdb->get_var("SELECT count(id) FROM {$wpdb->prefix}" . SAFETAG_EXCLUSION_LIST_TABLE );
    }
    private function get_items($args = []){
      global $wpdb;
      $table_name = $wpdb->prefix . SAFETAG_EXCLUSION_LIST_TABLE;
      $defaults = [
        'per_page' => 20,
        'offset'   => 0,
        'orderby'  => 'created_at',
        'order'    => 'DESC'
      ];
      $args = wp_parse_args($args, $defaults);

      $sql = "SELECT *
              FROM $table_name
              ORDER BY {$args['orderby']} {$args['order']}
              LIMIT %d OFFSET %d";

      $sql = $wpdb->prepare($sql, $args['per_page'], $args['offset']);
      return $wpdb->get_results($sql, ARRAY_A);
    }
    private function post_count(){
      $post_count = Safetag_Db_Management::get_exclusion_list_post_count();
      $count_result = [];
      if( !empty( $post_count['result'] ) ){ 
          foreach ($post_count['result']  as $value) {
          $count_result[$value->campaign_id] = $value->count;
        }
      }
      return $count_result;
    }
}