<?php

/**
 * Define all safetag API endpoints.
 *
 * @since      1.0.0
 * @package    safetag
 * @subpackage safetag/includes
 * @author     Your Name <email@example.com>
 */

class Safetag_API
{
    public function register()
    {
        register_rest_route('safetag-api/v1', '/iabtags(?:/(?P<search>\d+))?', array(
            'methods'             => 'GET',
            'callback'            => [$this, 'get_safetag_iab_tagas'],
            'permission_callback' => [$this, 'user_validation_middleware'],
            'args'                => ['search' => []],
        ));

        register_rest_route('safetag-api/v1', '/audiencetags(?:/(?P<search>\d+))?', array(
            'methods'             => 'GET',
            'callback'            => [$this, 'get_safetag_iab_audience_tags'],
            'permission_callback' => [$this, 'user_validation_middleware'],
            'args'                => ['search' => []],
        ));

        register_rest_route('safetag-api/v1', '/post-campaign/(?P<post_id>\d+)', array(
            'methods'             => 'GET',
            'callback'            => [$this, 'get_safetag_post_setting'],
            'permission_callback' => function () {
                return true;
            },
            'args'                => ['post_id' => []],
        ));
    }

    public function user_validation_middleware()
    {
        wp_create_nonce('wp_rest');
        return is_user_logged_in();
    }

    public function get_safetag_iab_tagas($request)
    {
        $search = $request['search'];
        $json_path = plugin_dir_path(dirname(__FILE__)) . 'admin/js/iab-tags-resources.json';
        $json = json_decode(file_get_contents($json_path), true);

        $result_filtered = array_filter($json, function ($var) use ($search) {
            return preg_match("/{$search}/i", $var['tax_name']);
        });

        return array_slice($result_filtered, 0, 1200, true);
    }

    public function get_safetag_iab_audience_tags($request)
    {
        $search = $request['search'];
        $json_path = plugin_dir_path(dirname(__FILE__)) . 'admin/js/iab-audience-tags.json';
        $json = json_decode(file_get_contents($json_path), true);

        $result_filtered = array_filter($json, function ($var) use ($search) {
            return preg_match("/{$search}/i", $var['tax_name']);
        });

        return array_slice($result_filtered, 0, 1200, true);
    }

    public function get_safetag_post_setting($request)
    {
        $post_id = $request['post_id'];
        $post_status = get_post_status($post_id);
        $is_post_id_valid = $post_status != false && $post_status == 'publish';

        $safetag_hide_programmatic_ads = false;
        $st_meta_tags = "";
        $keyword_result = "";
        $keyword_result_is_pending = false;
        $safetag_meta_tags = $iab_tags_items = [];
        if ($is_post_id_valid) {

            $safetag_hide_programmatic_ads =  true;
            if ($safetag_hide_programmatic_ads) {
                $st_meta_tags = json_decode( get_post_meta($post_id, 'safetag_meta_tags', true))?? [];
                $st_audience_tags = json_decode( get_option('site_audience_iab_tags'))?? [];
                $st_meta_tags = array_unique( array_merge($st_meta_tags, $st_audience_tags));
                $json_path = plugin_dir_path(dirname(__FILE__)) . 'admin/js/iab-audience-tags.json';
                $iab_tags = json_decode(file_get_contents($json_path), true);
                $index = ['rtb','taxonomy','taxonomy_name'];
                foreach ( $iab_tags as $value) {
                  if(!empty($value['tier']))
                  $iab_tags_items[ $value['id'] ]['tier'] = $value['tier'];
                }
                
                if( !empty($st_meta_tags)){
                  
                  foreach ($st_meta_tags as $tid) {                    
                    if(!empty($iab_tags_items[$tid])){
                      
                      foreach ( $iab_tags_items[$tid]['tier'] as $key => $value) {
                        switch ($key) {
                          case 0:
                            $section = 'cat';
                            break;
                          case 1:
                            $section = 'sectioncat';
                            break;
                          case 2:
                            $section = 'pagecat';
                            break;
                        }
                        
                        if(!empty($value['rtb']))
                        $safetag_meta_tags['rtb'][$section][$value['name']] = $value['rtb'];
                        
                        $safetag_meta_tags['taxonomy'][$section][$value['name']] = $value['id'];
                        $safetag_meta_tags['taxonomy_name'][$section][$value['name']] = $value['name'];                        
                      }

                    }
                  }

                 foreach ($st_meta_tags as $tid) {                    
                    if(!empty($iab_tags_items[$tid])){
                      
                      foreach ( $iab_tags_items[$tid]['tier'] as $key => $value) {
                        switch ($key) {
                          case 0:
                            $section = 'cat';
                            break;
                          case 1:
                            $section = 'sectioncat';
                            break;
                          case 2:
                            $section = 'pagecat';
                            break;
                        }
                        
                        foreach ($index as $index_name) {
                          
                          if(!empty($safetag_meta_tags[$index_name]))
                          $safetag_meta_tags[$index_name][$section] = array_values($safetag_meta_tags[$index_name][$section]);
                        }
                                                
                      }
                    }
                  }                  
                }
                
                $keyword_result_is_pending = count(Safetag_Db_Management::is_pending_keywords_result_by_post_id($post_id)) > 0;
                if (!$keyword_result_is_pending) {
                    $keyword_result = json_encode(Safetag_Db_Management::get_keywords_result_by_post_id($post_id));
                }
            }
        }

        return [
            'is_valid' => $is_post_id_valid,
            'post_id' => $post_id,
            'enable' => $safetag_hide_programmatic_ads,
            'tags' => $safetag_meta_tags,
            "keyword_result_is_pending" => $keyword_result_is_pending,
            'keyword_result' => json_decode($keyword_result)
        ];
    }
}
